@@ -1,9 +1,9 @@
 ##############################################################################
 #
 #  Data::Tools perl module
-#  2013-2019 (c) Vladi Belperchinov-Shabanski "Cade"
-#  http://cade.datamax.bg
-#  <cade@bis.bg> <cade@biscom.net> <cade@datamax.bg> <cade@cpan.org>
+#  Copyright (c) 2013-2022 Vladi Belperchinov-Shabanski "Cade" 
+#        <cade@noxrun.com> <cade@bis.bg> <cade@cpan.org>
+#  http://cade.noxrun.com/  
 #
 #  GPL
 #
@@ -16,7 +16,7 @@ use Data::Tools;
 use Date::Calc qw(:all);
 use Time::JulianDay;
 
-our $VERSION = '1.25';
+our $VERSION = '1.27';
 
 our @ISA    = qw( Exporter );
 our @EXPORT = qw(
@@ -585,10 +585,8 @@ I know this is no good for longer sentences but works fine in this case.
 =head1 AUTHOR
 
   Vladi Belperchinov-Shabanski "Cade"
-
-  <cade@bis.bg> <cade@biscom.net> <cade@datamax.bg> <cade@cpan.org>
-
-  http://cade.datamax.bg
+        <cade@noxrun.com> <cade@bis.bg> <cade@cpan.org>
+  http://cade.noxrun.com/  
 
 
 =cut
